@@ -4,10 +4,9 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-
-from ..models.absolute_timing_get import AbsoluteTimingGet
-from ..models.cron_timing_get import CronTimingGet
-from ..models.relative_timing_get import RelativeTimingGet
+from myst.openapi.models.absolute_timing_get import AbsoluteTimingGet
+from myst.openapi.models.cron_timing_get import CronTimingGet
+from myst.openapi.models.relative_timing_get import RelativeTimingGet
 
 
 class BacktestGet(base_model.BaseModel):
@@ -16,7 +15,6 @@ class BacktestGet(base_model.BaseModel):
     uuid: str
     create_time: str
     title: str
-    description: str
     test_start_time: str
     test_end_time: str
     fit_start_timing: Union[AbsoluteTimingGet, RelativeTimingGet]
@@ -30,3 +28,4 @@ class BacktestGet(base_model.BaseModel):
     creator: str
     object_: Optional[Literal["Backtest"]] = Field("Backtest", alias="object")
     update_time: Optional[str] = None
+    description: Optional[str] = None
