@@ -1,4 +1,4 @@
-from typing import Any, List, Optional, Union
+from typing import Dict, List, Optional, Union
 
 from pydantic import Field
 from typing_extensions import Literal
@@ -16,4 +16,4 @@ class TimeDataset(base_model.BaseModel):
     data: List[TimeDatasetRow]
     coordinate_labels: Optional[List[List[Union[int, str]]]] = None
     axis_labels: Optional[List[Union[int, str]]] = None
-    metadata: Optional[Any] = None
+    metadata: Optional[Dict[str, Optional[Union[str, int, float, bool]]]] = None
